# This file is automatically generated in base/Makefile
const MACHINE = "i686-linux-gnu"
const libm_name = "libopenlibm"
const USE_BLAS64 = false
const USE_GPL_LIBS = true
const libllvm_version_string = "20.1.8jl"
const libllvm_name = "libLLVM-20jl"
const VERSION_STRING = "1.13.0-rc1"
const TAGGED_RELEASE_BANNER = "Official https://julialang.org release"
const SYSCONFDIR = "../etc"
const DATAROOTDIR = "../share"
const DOCDIR = "../share/doc/julia"
const LIBDIR = "../lib"
const LIBEXECDIR = "../libexec"
const PRIVATE_LIBDIR = "../lib/julia"
const PRIVATE_LIBEXECDIR = "../libexec/julia"
const INCLUDEDIR = "../include"
const SOURCEDIR = "/cache/build/builder-amdci4-2/julialang/julia-release-1-dot-13"
const DARWIN_FRAMEWORK = false
const BUILD_TRIPLET = "i686-linux-gnu-libgfortran5-cxx11"
